@@ -47,7 +47,7 @@ class Task(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.steps:
                 raise MissingRequiredArgumentError(argument="steps")
             self.res["spec"] = {}
